# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkAttachedDataNetworkArgs', 'NetworkAttachedDataNetwork']

@pulumi.input_type
class NetworkAttachedDataNetworkArgs:
    def __init__(__self__, *,
                 dns_addresses: pulumi.Input[Sequence[pulumi.Input[str]]],
                 mobile_network_data_network_name: pulumi.Input[str],
                 mobile_network_packet_core_data_plane_id: pulumi.Input[str],
                 location: Optional[pulumi.Input[str]] = None,
                 network_address_port_translation: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
                 user_plane_access_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NetworkAttachedDataNetwork resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_addresses: Specifies the DNS servers to signal to UEs to use for this attached data network.
        :param pulumi.Input[str] mobile_network_data_network_name: Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_packet_core_data_plane_id: Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs'] network_address_port_translation: A `network_address_port_translation` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        :param pulumi.Input[str] user_plane_access_ipv4_address: The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_gateway: The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_subnet: The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_name: Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        NetworkAttachedDataNetworkArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            dns_addresses=dns_addresses,
            mobile_network_data_network_name=mobile_network_data_network_name,
            mobile_network_packet_core_data_plane_id=mobile_network_packet_core_data_plane_id,
            location=location,
            network_address_port_translation=network_address_port_translation,
            tags=tags,
            user_equipment_address_pool_prefixes=user_equipment_address_pool_prefixes,
            user_equipment_static_address_pool_prefixes=user_equipment_static_address_pool_prefixes,
            user_plane_access_ipv4_address=user_plane_access_ipv4_address,
            user_plane_access_ipv4_gateway=user_plane_access_ipv4_gateway,
            user_plane_access_ipv4_subnet=user_plane_access_ipv4_subnet,
            user_plane_access_name=user_plane_access_name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
             mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
             location: Optional[pulumi.Input[str]] = None,
             network_address_port_translation: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] = None,
             tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
             user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
             user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
             user_plane_access_name: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if dns_addresses is None and 'dnsAddresses' in kwargs:
            dns_addresses = kwargs['dnsAddresses']
        if dns_addresses is None:
            raise TypeError("Missing 'dns_addresses' argument")
        if mobile_network_data_network_name is None and 'mobileNetworkDataNetworkName' in kwargs:
            mobile_network_data_network_name = kwargs['mobileNetworkDataNetworkName']
        if mobile_network_data_network_name is None:
            raise TypeError("Missing 'mobile_network_data_network_name' argument")
        if mobile_network_packet_core_data_plane_id is None and 'mobileNetworkPacketCoreDataPlaneId' in kwargs:
            mobile_network_packet_core_data_plane_id = kwargs['mobileNetworkPacketCoreDataPlaneId']
        if mobile_network_packet_core_data_plane_id is None:
            raise TypeError("Missing 'mobile_network_packet_core_data_plane_id' argument")
        if network_address_port_translation is None and 'networkAddressPortTranslation' in kwargs:
            network_address_port_translation = kwargs['networkAddressPortTranslation']
        if user_equipment_address_pool_prefixes is None and 'userEquipmentAddressPoolPrefixes' in kwargs:
            user_equipment_address_pool_prefixes = kwargs['userEquipmentAddressPoolPrefixes']
        if user_equipment_static_address_pool_prefixes is None and 'userEquipmentStaticAddressPoolPrefixes' in kwargs:
            user_equipment_static_address_pool_prefixes = kwargs['userEquipmentStaticAddressPoolPrefixes']
        if user_plane_access_ipv4_address is None and 'userPlaneAccessIpv4Address' in kwargs:
            user_plane_access_ipv4_address = kwargs['userPlaneAccessIpv4Address']
        if user_plane_access_ipv4_gateway is None and 'userPlaneAccessIpv4Gateway' in kwargs:
            user_plane_access_ipv4_gateway = kwargs['userPlaneAccessIpv4Gateway']
        if user_plane_access_ipv4_subnet is None and 'userPlaneAccessIpv4Subnet' in kwargs:
            user_plane_access_ipv4_subnet = kwargs['userPlaneAccessIpv4Subnet']
        if user_plane_access_name is None and 'userPlaneAccessName' in kwargs:
            user_plane_access_name = kwargs['userPlaneAccessName']

        _setter("dns_addresses", dns_addresses)
        _setter("mobile_network_data_network_name", mobile_network_data_network_name)
        _setter("mobile_network_packet_core_data_plane_id", mobile_network_packet_core_data_plane_id)
        if location is not None:
            _setter("location", location)
        if network_address_port_translation is not None:
            _setter("network_address_port_translation", network_address_port_translation)
        if tags is not None:
            _setter("tags", tags)
        if user_equipment_address_pool_prefixes is not None:
            _setter("user_equipment_address_pool_prefixes", user_equipment_address_pool_prefixes)
        if user_equipment_static_address_pool_prefixes is not None:
            _setter("user_equipment_static_address_pool_prefixes", user_equipment_static_address_pool_prefixes)
        if user_plane_access_ipv4_address is not None:
            _setter("user_plane_access_ipv4_address", user_plane_access_ipv4_address)
        if user_plane_access_ipv4_gateway is not None:
            _setter("user_plane_access_ipv4_gateway", user_plane_access_ipv4_gateway)
        if user_plane_access_ipv4_subnet is not None:
            _setter("user_plane_access_ipv4_subnet", user_plane_access_ipv4_subnet)
        if user_plane_access_name is not None:
            _setter("user_plane_access_name", user_plane_access_name)

    @property
    @pulumi.getter(name="dnsAddresses")
    def dns_addresses(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Specifies the DNS servers to signal to UEs to use for this attached data network.
        """
        return pulumi.get(self, "dns_addresses")

    @dns_addresses.setter
    def dns_addresses(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "dns_addresses", value)

    @property
    @pulumi.getter(name="mobileNetworkDataNetworkName")
    def mobile_network_data_network_name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_data_network_name")

    @mobile_network_data_network_name.setter
    def mobile_network_data_network_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "mobile_network_data_network_name", value)

    @property
    @pulumi.getter(name="mobileNetworkPacketCoreDataPlaneId")
    def mobile_network_packet_core_data_plane_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_packet_core_data_plane_id")

    @mobile_network_packet_core_data_plane_id.setter
    def mobile_network_packet_core_data_plane_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "mobile_network_packet_core_data_plane_id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="networkAddressPortTranslation")
    def network_address_port_translation(self) -> Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]:
        """
        A `network_address_port_translation` block as defined below.
        """
        return pulumi.get(self, "network_address_port_translation")

    @network_address_port_translation.setter
    def network_address_port_translation(self, value: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]):
        pulumi.set(self, "network_address_port_translation", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="userEquipmentAddressPoolPrefixes")
    def user_equipment_address_pool_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "user_equipment_address_pool_prefixes")

    @user_equipment_address_pool_prefixes.setter
    def user_equipment_address_pool_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_equipment_address_pool_prefixes", value)

    @property
    @pulumi.getter(name="userEquipmentStaticAddressPoolPrefixes")
    def user_equipment_static_address_pool_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "user_equipment_static_address_pool_prefixes")

    @user_equipment_static_address_pool_prefixes.setter
    def user_equipment_static_address_pool_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_equipment_static_address_pool_prefixes", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Address")
    def user_plane_access_ipv4_address(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_address")

    @user_plane_access_ipv4_address.setter
    def user_plane_access_ipv4_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_address", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Gateway")
    def user_plane_access_ipv4_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_gateway")

    @user_plane_access_ipv4_gateway.setter
    def user_plane_access_ipv4_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_gateway", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Subnet")
    def user_plane_access_ipv4_subnet(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_subnet")

    @user_plane_access_ipv4_subnet.setter
    def user_plane_access_ipv4_subnet(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_subnet", value)

    @property
    @pulumi.getter(name="userPlaneAccessName")
    def user_plane_access_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_name")

    @user_plane_access_name.setter
    def user_plane_access_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_name", value)


@pulumi.input_type
class _NetworkAttachedDataNetworkState:
    def __init__(__self__, *,
                 dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
                 mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
                 network_address_port_translation: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
                 user_plane_access_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NetworkAttachedDataNetwork resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_addresses: Specifies the DNS servers to signal to UEs to use for this attached data network.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_data_network_name: Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_packet_core_data_plane_id: Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs'] network_address_port_translation: A `network_address_port_translation` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        :param pulumi.Input[str] user_plane_access_ipv4_address: The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_gateway: The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_subnet: The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_name: Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        _NetworkAttachedDataNetworkState._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            dns_addresses=dns_addresses,
            location=location,
            mobile_network_data_network_name=mobile_network_data_network_name,
            mobile_network_packet_core_data_plane_id=mobile_network_packet_core_data_plane_id,
            network_address_port_translation=network_address_port_translation,
            tags=tags,
            user_equipment_address_pool_prefixes=user_equipment_address_pool_prefixes,
            user_equipment_static_address_pool_prefixes=user_equipment_static_address_pool_prefixes,
            user_plane_access_ipv4_address=user_plane_access_ipv4_address,
            user_plane_access_ipv4_gateway=user_plane_access_ipv4_gateway,
            user_plane_access_ipv4_subnet=user_plane_access_ipv4_subnet,
            user_plane_access_name=user_plane_access_name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             location: Optional[pulumi.Input[str]] = None,
             mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
             mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
             network_address_port_translation: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] = None,
             tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
             user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
             user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
             user_plane_access_name: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if dns_addresses is None and 'dnsAddresses' in kwargs:
            dns_addresses = kwargs['dnsAddresses']
        if mobile_network_data_network_name is None and 'mobileNetworkDataNetworkName' in kwargs:
            mobile_network_data_network_name = kwargs['mobileNetworkDataNetworkName']
        if mobile_network_packet_core_data_plane_id is None and 'mobileNetworkPacketCoreDataPlaneId' in kwargs:
            mobile_network_packet_core_data_plane_id = kwargs['mobileNetworkPacketCoreDataPlaneId']
        if network_address_port_translation is None and 'networkAddressPortTranslation' in kwargs:
            network_address_port_translation = kwargs['networkAddressPortTranslation']
        if user_equipment_address_pool_prefixes is None and 'userEquipmentAddressPoolPrefixes' in kwargs:
            user_equipment_address_pool_prefixes = kwargs['userEquipmentAddressPoolPrefixes']
        if user_equipment_static_address_pool_prefixes is None and 'userEquipmentStaticAddressPoolPrefixes' in kwargs:
            user_equipment_static_address_pool_prefixes = kwargs['userEquipmentStaticAddressPoolPrefixes']
        if user_plane_access_ipv4_address is None and 'userPlaneAccessIpv4Address' in kwargs:
            user_plane_access_ipv4_address = kwargs['userPlaneAccessIpv4Address']
        if user_plane_access_ipv4_gateway is None and 'userPlaneAccessIpv4Gateway' in kwargs:
            user_plane_access_ipv4_gateway = kwargs['userPlaneAccessIpv4Gateway']
        if user_plane_access_ipv4_subnet is None and 'userPlaneAccessIpv4Subnet' in kwargs:
            user_plane_access_ipv4_subnet = kwargs['userPlaneAccessIpv4Subnet']
        if user_plane_access_name is None and 'userPlaneAccessName' in kwargs:
            user_plane_access_name = kwargs['userPlaneAccessName']

        if dns_addresses is not None:
            _setter("dns_addresses", dns_addresses)
        if location is not None:
            _setter("location", location)
        if mobile_network_data_network_name is not None:
            _setter("mobile_network_data_network_name", mobile_network_data_network_name)
        if mobile_network_packet_core_data_plane_id is not None:
            _setter("mobile_network_packet_core_data_plane_id", mobile_network_packet_core_data_plane_id)
        if network_address_port_translation is not None:
            _setter("network_address_port_translation", network_address_port_translation)
        if tags is not None:
            _setter("tags", tags)
        if user_equipment_address_pool_prefixes is not None:
            _setter("user_equipment_address_pool_prefixes", user_equipment_address_pool_prefixes)
        if user_equipment_static_address_pool_prefixes is not None:
            _setter("user_equipment_static_address_pool_prefixes", user_equipment_static_address_pool_prefixes)
        if user_plane_access_ipv4_address is not None:
            _setter("user_plane_access_ipv4_address", user_plane_access_ipv4_address)
        if user_plane_access_ipv4_gateway is not None:
            _setter("user_plane_access_ipv4_gateway", user_plane_access_ipv4_gateway)
        if user_plane_access_ipv4_subnet is not None:
            _setter("user_plane_access_ipv4_subnet", user_plane_access_ipv4_subnet)
        if user_plane_access_name is not None:
            _setter("user_plane_access_name", user_plane_access_name)

    @property
    @pulumi.getter(name="dnsAddresses")
    def dns_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the DNS servers to signal to UEs to use for this attached data network.
        """
        return pulumi.get(self, "dns_addresses")

    @dns_addresses.setter
    def dns_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_addresses", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="mobileNetworkDataNetworkName")
    def mobile_network_data_network_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_data_network_name")

    @mobile_network_data_network_name.setter
    def mobile_network_data_network_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mobile_network_data_network_name", value)

    @property
    @pulumi.getter(name="mobileNetworkPacketCoreDataPlaneId")
    def mobile_network_packet_core_data_plane_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_packet_core_data_plane_id")

    @mobile_network_packet_core_data_plane_id.setter
    def mobile_network_packet_core_data_plane_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mobile_network_packet_core_data_plane_id", value)

    @property
    @pulumi.getter(name="networkAddressPortTranslation")
    def network_address_port_translation(self) -> Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]:
        """
        A `network_address_port_translation` block as defined below.
        """
        return pulumi.get(self, "network_address_port_translation")

    @network_address_port_translation.setter
    def network_address_port_translation(self, value: Optional[pulumi.Input['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]):
        pulumi.set(self, "network_address_port_translation", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="userEquipmentAddressPoolPrefixes")
    def user_equipment_address_pool_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "user_equipment_address_pool_prefixes")

    @user_equipment_address_pool_prefixes.setter
    def user_equipment_address_pool_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_equipment_address_pool_prefixes", value)

    @property
    @pulumi.getter(name="userEquipmentStaticAddressPoolPrefixes")
    def user_equipment_static_address_pool_prefixes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "user_equipment_static_address_pool_prefixes")

    @user_equipment_static_address_pool_prefixes.setter
    def user_equipment_static_address_pool_prefixes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_equipment_static_address_pool_prefixes", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Address")
    def user_plane_access_ipv4_address(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_address")

    @user_plane_access_ipv4_address.setter
    def user_plane_access_ipv4_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_address", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Gateway")
    def user_plane_access_ipv4_gateway(self) -> Optional[pulumi.Input[str]]:
        """
        The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_gateway")

    @user_plane_access_ipv4_gateway.setter
    def user_plane_access_ipv4_gateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_gateway", value)

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Subnet")
    def user_plane_access_ipv4_subnet(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_subnet")

    @user_plane_access_ipv4_subnet.setter
    def user_plane_access_ipv4_subnet(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_ipv4_subnet", value)

    @property
    @pulumi.getter(name="userPlaneAccessName")
    def user_plane_access_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_name")

    @user_plane_access_name.setter
    def user_plane_access_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_plane_access_name", value)


class NetworkAttachedDataNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
                 mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
                 network_address_port_translation: Optional[pulumi.Input[pulumi.InputType['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
                 user_plane_access_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Mobile Network Attached Data Network.

        ## Import

        Mobile Network Attached Data Network can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:mobile/networkAttachedDataNetwork:NetworkAttachedDataNetwork example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.MobileNetwork/packetCoreControlPlanes/packetCoreControlPlane1/packetCoreDataPlanes/packetCoreDataPlane1/attachedDataNetworks/attachedDataNetwork1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_addresses: Specifies the DNS servers to signal to UEs to use for this attached data network.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_data_network_name: Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_packet_core_data_plane_id: Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[pulumi.InputType['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] network_address_port_translation: A `network_address_port_translation` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        :param pulumi.Input[str] user_plane_access_ipv4_address: The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_gateway: The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_subnet: The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_name: Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkAttachedDataNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Mobile Network Attached Data Network.

        ## Import

        Mobile Network Attached Data Network can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:mobile/networkAttachedDataNetwork:NetworkAttachedDataNetwork example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.MobileNetwork/packetCoreControlPlanes/packetCoreControlPlane1/packetCoreDataPlanes/packetCoreDataPlane1/attachedDataNetworks/attachedDataNetwork1
        ```

        :param str resource_name: The name of the resource.
        :param NetworkAttachedDataNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkAttachedDataNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            kwargs = kwargs or {}
            def _setter(key, value):
                kwargs[key] = value
            NetworkAttachedDataNetworkArgs._configure(_setter, **kwargs)
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
                 mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
                 network_address_port_translation: Optional[pulumi.Input[pulumi.InputType['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
                 user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
                 user_plane_access_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkAttachedDataNetworkArgs.__new__(NetworkAttachedDataNetworkArgs)

            if dns_addresses is None and not opts.urn:
                raise TypeError("Missing required property 'dns_addresses'")
            __props__.__dict__["dns_addresses"] = dns_addresses
            __props__.__dict__["location"] = location
            if mobile_network_data_network_name is None and not opts.urn:
                raise TypeError("Missing required property 'mobile_network_data_network_name'")
            __props__.__dict__["mobile_network_data_network_name"] = mobile_network_data_network_name
            if mobile_network_packet_core_data_plane_id is None and not opts.urn:
                raise TypeError("Missing required property 'mobile_network_packet_core_data_plane_id'")
            __props__.__dict__["mobile_network_packet_core_data_plane_id"] = mobile_network_packet_core_data_plane_id
            network_address_port_translation = _utilities.configure(network_address_port_translation, NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs, True)
            __props__.__dict__["network_address_port_translation"] = network_address_port_translation
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_equipment_address_pool_prefixes"] = user_equipment_address_pool_prefixes
            __props__.__dict__["user_equipment_static_address_pool_prefixes"] = user_equipment_static_address_pool_prefixes
            __props__.__dict__["user_plane_access_ipv4_address"] = user_plane_access_ipv4_address
            __props__.__dict__["user_plane_access_ipv4_gateway"] = user_plane_access_ipv4_gateway
            __props__.__dict__["user_plane_access_ipv4_subnet"] = user_plane_access_ipv4_subnet
            __props__.__dict__["user_plane_access_name"] = user_plane_access_name
        super(NetworkAttachedDataNetwork, __self__).__init__(
            'azure:mobile/networkAttachedDataNetwork:NetworkAttachedDataNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dns_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            location: Optional[pulumi.Input[str]] = None,
            mobile_network_data_network_name: Optional[pulumi.Input[str]] = None,
            mobile_network_packet_core_data_plane_id: Optional[pulumi.Input[str]] = None,
            network_address_port_translation: Optional[pulumi.Input[pulumi.InputType['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            user_equipment_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            user_equipment_static_address_pool_prefixes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            user_plane_access_ipv4_address: Optional[pulumi.Input[str]] = None,
            user_plane_access_ipv4_gateway: Optional[pulumi.Input[str]] = None,
            user_plane_access_ipv4_subnet: Optional[pulumi.Input[str]] = None,
            user_plane_access_name: Optional[pulumi.Input[str]] = None) -> 'NetworkAttachedDataNetwork':
        """
        Get an existing NetworkAttachedDataNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_addresses: Specifies the DNS servers to signal to UEs to use for this attached data network.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_data_network_name: Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[str] mobile_network_packet_core_data_plane_id: Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        :param pulumi.Input[pulumi.InputType['NetworkAttachedDataNetworkNetworkAddressPortTranslationArgs']] network_address_port_translation: A `network_address_port_translation` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        :param pulumi.Input[str] user_plane_access_ipv4_address: The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_gateway: The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_ipv4_subnet: The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        :param pulumi.Input[str] user_plane_access_name: Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkAttachedDataNetworkState.__new__(_NetworkAttachedDataNetworkState)

        __props__.__dict__["dns_addresses"] = dns_addresses
        __props__.__dict__["location"] = location
        __props__.__dict__["mobile_network_data_network_name"] = mobile_network_data_network_name
        __props__.__dict__["mobile_network_packet_core_data_plane_id"] = mobile_network_packet_core_data_plane_id
        __props__.__dict__["network_address_port_translation"] = network_address_port_translation
        __props__.__dict__["tags"] = tags
        __props__.__dict__["user_equipment_address_pool_prefixes"] = user_equipment_address_pool_prefixes
        __props__.__dict__["user_equipment_static_address_pool_prefixes"] = user_equipment_static_address_pool_prefixes
        __props__.__dict__["user_plane_access_ipv4_address"] = user_plane_access_ipv4_address
        __props__.__dict__["user_plane_access_ipv4_gateway"] = user_plane_access_ipv4_gateway
        __props__.__dict__["user_plane_access_ipv4_subnet"] = user_plane_access_ipv4_subnet
        __props__.__dict__["user_plane_access_name"] = user_plane_access_name
        return NetworkAttachedDataNetwork(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dnsAddresses")
    def dns_addresses(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies the DNS servers to signal to UEs to use for this attached data network.
        """
        return pulumi.get(self, "dns_addresses")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        Specifies the Azure Region where the Mobile Network Attached Data Network should exist. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="mobileNetworkDataNetworkName")
    def mobile_network_data_network_name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the `mobile.NetworkDataNetwork` which the Attached Data Network belongs to, Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_data_network_name")

    @property
    @pulumi.getter(name="mobileNetworkPacketCoreDataPlaneId")
    def mobile_network_packet_core_data_plane_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the `mobile.NetworkPacketCoreDataPlane` which the Mobile Network Attached Data Network belongs to. Changing this forces a new Mobile Network Attached Data Network to be created.
        """
        return pulumi.get(self, "mobile_network_packet_core_data_plane_id")

    @property
    @pulumi.getter(name="networkAddressPortTranslation")
    def network_address_port_translation(self) -> pulumi.Output[Optional['outputs.NetworkAttachedDataNetworkNetworkAddressPortTranslation']]:
        """
        A `network_address_port_translation` block as defined below.
        """
        return pulumi.get(self, "network_address_port_translation")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags which should be assigned to the Mobile Network Attached Data Network.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="userEquipmentAddressPoolPrefixes")
    def user_equipment_address_pool_prefixes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "user_equipment_address_pool_prefixes")

    @property
    @pulumi.getter(name="userEquipmentStaticAddressPoolPrefixes")
    def user_equipment_static_address_pool_prefixes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "user_equipment_static_address_pool_prefixes")

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Address")
    def user_plane_access_ipv4_address(self) -> pulumi.Output[Optional[str]]:
        """
        The IPv4 address for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_address")

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Gateway")
    def user_plane_access_ipv4_gateway(self) -> pulumi.Output[Optional[str]]:
        """
        The default IPv4 gateway for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_gateway")

    @property
    @pulumi.getter(name="userPlaneAccessIpv4Subnet")
    def user_plane_access_ipv4_subnet(self) -> pulumi.Output[Optional[str]]:
        """
        The IPv4 subnet for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_ipv4_subnet")

    @property
    @pulumi.getter(name="userPlaneAccessName")
    def user_plane_access_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the logical name for the user data plane interface. This should match one of the interfaces configured on your Azure Stack Edge device.
        """
        return pulumi.get(self, "user_plane_access_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatasetAzureBlobArgs', 'DatasetAzureBlob']

@pulumi.input_type
class DatasetAzureBlobArgs:
    def __init__(__self__, *,
                 data_factory_id: pulumi.Input[str],
                 linked_service_name: pulumi.Input[str],
                 additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
                 dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
                 filename: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]] = None):
        """
        The set of arguments for constructing a DatasetAzureBlob resource.
        :param pulumi.Input[str] data_factory_id: The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        :param pulumi.Input[str] linked_service_name: The Data Factory Linked Service name in which to associate the Dataset with.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_properties: A map of additional properties to associate with the Data Factory Dataset.
               
               The following supported arguments are specific to Azure Blob Dataset:
        :param pulumi.Input[Sequence[pulumi.Input[str]]] annotations: List of tags that can be used for describing the Data Factory Dataset.
        :param pulumi.Input[str] description: The description for the Data Factory Dataset.
        :param pulumi.Input[bool] dynamic_filename_enabled: Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[bool] dynamic_path_enabled: Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[str] filename: The filename of the Azure Blob.
        :param pulumi.Input[str] folder: The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        :param pulumi.Input[str] name: Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] parameters: A map of parameters to associate with the Data Factory Dataset.
        :param pulumi.Input[str] path: The path of the Azure Blob.
        :param pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]] schema_columns: A `schema_column` block as defined below.
        """
        DatasetAzureBlobArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            data_factory_id=data_factory_id,
            linked_service_name=linked_service_name,
            additional_properties=additional_properties,
            annotations=annotations,
            description=description,
            dynamic_filename_enabled=dynamic_filename_enabled,
            dynamic_path_enabled=dynamic_path_enabled,
            filename=filename,
            folder=folder,
            name=name,
            parameters=parameters,
            path=path,
            schema_columns=schema_columns,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             data_factory_id: Optional[pulumi.Input[str]] = None,
             linked_service_name: Optional[pulumi.Input[str]] = None,
             additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             description: Optional[pulumi.Input[str]] = None,
             dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
             dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
             filename: Optional[pulumi.Input[str]] = None,
             folder: Optional[pulumi.Input[str]] = None,
             name: Optional[pulumi.Input[str]] = None,
             parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             path: Optional[pulumi.Input[str]] = None,
             schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if data_factory_id is None and 'dataFactoryId' in kwargs:
            data_factory_id = kwargs['dataFactoryId']
        if data_factory_id is None:
            raise TypeError("Missing 'data_factory_id' argument")
        if linked_service_name is None and 'linkedServiceName' in kwargs:
            linked_service_name = kwargs['linkedServiceName']
        if linked_service_name is None:
            raise TypeError("Missing 'linked_service_name' argument")
        if additional_properties is None and 'additionalProperties' in kwargs:
            additional_properties = kwargs['additionalProperties']
        if dynamic_filename_enabled is None and 'dynamicFilenameEnabled' in kwargs:
            dynamic_filename_enabled = kwargs['dynamicFilenameEnabled']
        if dynamic_path_enabled is None and 'dynamicPathEnabled' in kwargs:
            dynamic_path_enabled = kwargs['dynamicPathEnabled']
        if schema_columns is None and 'schemaColumns' in kwargs:
            schema_columns = kwargs['schemaColumns']

        _setter("data_factory_id", data_factory_id)
        _setter("linked_service_name", linked_service_name)
        if additional_properties is not None:
            _setter("additional_properties", additional_properties)
        if annotations is not None:
            _setter("annotations", annotations)
        if description is not None:
            _setter("description", description)
        if dynamic_filename_enabled is not None:
            _setter("dynamic_filename_enabled", dynamic_filename_enabled)
        if dynamic_path_enabled is not None:
            _setter("dynamic_path_enabled", dynamic_path_enabled)
        if filename is not None:
            _setter("filename", filename)
        if folder is not None:
            _setter("folder", folder)
        if name is not None:
            _setter("name", name)
        if parameters is not None:
            _setter("parameters", parameters)
        if path is not None:
            _setter("path", path)
        if schema_columns is not None:
            _setter("schema_columns", schema_columns)

    @property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> pulumi.Input[str]:
        """
        The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        """
        return pulumi.get(self, "data_factory_id")

    @data_factory_id.setter
    def data_factory_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_factory_id", value)

    @property
    @pulumi.getter(name="linkedServiceName")
    def linked_service_name(self) -> pulumi.Input[str]:
        """
        The Data Factory Linked Service name in which to associate the Dataset with.
        """
        return pulumi.get(self, "linked_service_name")

    @linked_service_name.setter
    def linked_service_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "linked_service_name", value)

    @property
    @pulumi.getter(name="additionalProperties")
    def additional_properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of additional properties to associate with the Data Factory Dataset.

        The following supported arguments are specific to Azure Blob Dataset:
        """
        return pulumi.get(self, "additional_properties")

    @additional_properties.setter
    def additional_properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "additional_properties", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of tags that can be used for describing the Data Factory Dataset.
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description for the Data Factory Dataset.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dynamicFilenameEnabled")
    def dynamic_filename_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_filename_enabled")

    @dynamic_filename_enabled.setter
    def dynamic_filename_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dynamic_filename_enabled", value)

    @property
    @pulumi.getter(name="dynamicPathEnabled")
    def dynamic_path_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_path_enabled")

    @dynamic_path_enabled.setter
    def dynamic_path_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dynamic_path_enabled", value)

    @property
    @pulumi.getter
    def filename(self) -> Optional[pulumi.Input[str]]:
        """
        The filename of the Azure Blob.
        """
        return pulumi.get(self, "filename")

    @filename.setter
    def filename(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filename", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[str]]:
        """
        The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of parameters to associate with the Data Factory Dataset.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the Azure Blob.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="schemaColumns")
    def schema_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]]:
        """
        A `schema_column` block as defined below.
        """
        return pulumi.get(self, "schema_columns")

    @schema_columns.setter
    def schema_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]]):
        pulumi.set(self, "schema_columns", value)


@pulumi.input_type
class _DatasetAzureBlobState:
    def __init__(__self__, *,
                 additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 data_factory_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
                 dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
                 filename: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 linked_service_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]] = None):
        """
        Input properties used for looking up and filtering DatasetAzureBlob resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_properties: A map of additional properties to associate with the Data Factory Dataset.
               
               The following supported arguments are specific to Azure Blob Dataset:
        :param pulumi.Input[Sequence[pulumi.Input[str]]] annotations: List of tags that can be used for describing the Data Factory Dataset.
        :param pulumi.Input[str] data_factory_id: The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        :param pulumi.Input[str] description: The description for the Data Factory Dataset.
        :param pulumi.Input[bool] dynamic_filename_enabled: Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[bool] dynamic_path_enabled: Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[str] filename: The filename of the Azure Blob.
        :param pulumi.Input[str] folder: The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        :param pulumi.Input[str] linked_service_name: The Data Factory Linked Service name in which to associate the Dataset with.
        :param pulumi.Input[str] name: Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] parameters: A map of parameters to associate with the Data Factory Dataset.
        :param pulumi.Input[str] path: The path of the Azure Blob.
        :param pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]] schema_columns: A `schema_column` block as defined below.
        """
        _DatasetAzureBlobState._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            additional_properties=additional_properties,
            annotations=annotations,
            data_factory_id=data_factory_id,
            description=description,
            dynamic_filename_enabled=dynamic_filename_enabled,
            dynamic_path_enabled=dynamic_path_enabled,
            filename=filename,
            folder=folder,
            linked_service_name=linked_service_name,
            name=name,
            parameters=parameters,
            path=path,
            schema_columns=schema_columns,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             data_factory_id: Optional[pulumi.Input[str]] = None,
             description: Optional[pulumi.Input[str]] = None,
             dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
             dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
             filename: Optional[pulumi.Input[str]] = None,
             folder: Optional[pulumi.Input[str]] = None,
             linked_service_name: Optional[pulumi.Input[str]] = None,
             name: Optional[pulumi.Input[str]] = None,
             parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             path: Optional[pulumi.Input[str]] = None,
             schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if additional_properties is None and 'additionalProperties' in kwargs:
            additional_properties = kwargs['additionalProperties']
        if data_factory_id is None and 'dataFactoryId' in kwargs:
            data_factory_id = kwargs['dataFactoryId']
        if dynamic_filename_enabled is None and 'dynamicFilenameEnabled' in kwargs:
            dynamic_filename_enabled = kwargs['dynamicFilenameEnabled']
        if dynamic_path_enabled is None and 'dynamicPathEnabled' in kwargs:
            dynamic_path_enabled = kwargs['dynamicPathEnabled']
        if linked_service_name is None and 'linkedServiceName' in kwargs:
            linked_service_name = kwargs['linkedServiceName']
        if schema_columns is None and 'schemaColumns' in kwargs:
            schema_columns = kwargs['schemaColumns']

        if additional_properties is not None:
            _setter("additional_properties", additional_properties)
        if annotations is not None:
            _setter("annotations", annotations)
        if data_factory_id is not None:
            _setter("data_factory_id", data_factory_id)
        if description is not None:
            _setter("description", description)
        if dynamic_filename_enabled is not None:
            _setter("dynamic_filename_enabled", dynamic_filename_enabled)
        if dynamic_path_enabled is not None:
            _setter("dynamic_path_enabled", dynamic_path_enabled)
        if filename is not None:
            _setter("filename", filename)
        if folder is not None:
            _setter("folder", folder)
        if linked_service_name is not None:
            _setter("linked_service_name", linked_service_name)
        if name is not None:
            _setter("name", name)
        if parameters is not None:
            _setter("parameters", parameters)
        if path is not None:
            _setter("path", path)
        if schema_columns is not None:
            _setter("schema_columns", schema_columns)

    @property
    @pulumi.getter(name="additionalProperties")
    def additional_properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of additional properties to associate with the Data Factory Dataset.

        The following supported arguments are specific to Azure Blob Dataset:
        """
        return pulumi.get(self, "additional_properties")

    @additional_properties.setter
    def additional_properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "additional_properties", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of tags that can be used for describing the Data Factory Dataset.
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        """
        return pulumi.get(self, "data_factory_id")

    @data_factory_id.setter
    def data_factory_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_factory_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description for the Data Factory Dataset.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dynamicFilenameEnabled")
    def dynamic_filename_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_filename_enabled")

    @dynamic_filename_enabled.setter
    def dynamic_filename_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dynamic_filename_enabled", value)

    @property
    @pulumi.getter(name="dynamicPathEnabled")
    def dynamic_path_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_path_enabled")

    @dynamic_path_enabled.setter
    def dynamic_path_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dynamic_path_enabled", value)

    @property
    @pulumi.getter
    def filename(self) -> Optional[pulumi.Input[str]]:
        """
        The filename of the Azure Blob.
        """
        return pulumi.get(self, "filename")

    @filename.setter
    def filename(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filename", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[str]]:
        """
        The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter(name="linkedServiceName")
    def linked_service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Data Factory Linked Service name in which to associate the Dataset with.
        """
        return pulumi.get(self, "linked_service_name")

    @linked_service_name.setter
    def linked_service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "linked_service_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of parameters to associate with the Data Factory Dataset.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the Azure Blob.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="schemaColumns")
    def schema_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]]:
        """
        A `schema_column` block as defined below.
        """
        return pulumi.get(self, "schema_columns")

    @schema_columns.setter
    def schema_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatasetAzureBlobSchemaColumnArgs']]]]):
        pulumi.set(self, "schema_columns", value)


class DatasetAzureBlob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 data_factory_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
                 dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
                 filename: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 linked_service_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatasetAzureBlobSchemaColumnArgs']]]]] = None,
                 __props__=None):
        """
        Manages an Azure Blob Dataset inside an Azure Data Factory.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.storage.get_account_output(name="storageaccountname",
            resource_group_name=example_resource_group.name)
        example_factory = azure.datafactory.Factory("exampleFactory",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_linked_service_azure_blob_storage = azure.datafactory.LinkedServiceAzureBlobStorage("exampleLinkedServiceAzureBlobStorage",
            data_factory_id=example_factory.id,
            connection_string=example_account.primary_connection_string)
        example_dataset_azure_blob = azure.datafactory.DatasetAzureBlob("exampleDatasetAzureBlob",
            data_factory_id=example_factory.id,
            linked_service_name=example_linked_service_azure_blob_storage.name,
            path="foo",
            filename="bar.png")
        ```

        ## Import

        Data Factory Datasets can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:datafactory/datasetAzureBlob:DatasetAzureBlob example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example/providers/Microsoft.DataFactory/factories/example/datasets/example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_properties: A map of additional properties to associate with the Data Factory Dataset.
               
               The following supported arguments are specific to Azure Blob Dataset:
        :param pulumi.Input[Sequence[pulumi.Input[str]]] annotations: List of tags that can be used for describing the Data Factory Dataset.
        :param pulumi.Input[str] data_factory_id: The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        :param pulumi.Input[str] description: The description for the Data Factory Dataset.
        :param pulumi.Input[bool] dynamic_filename_enabled: Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[bool] dynamic_path_enabled: Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[str] filename: The filename of the Azure Blob.
        :param pulumi.Input[str] folder: The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        :param pulumi.Input[str] linked_service_name: The Data Factory Linked Service name in which to associate the Dataset with.
        :param pulumi.Input[str] name: Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] parameters: A map of parameters to associate with the Data Factory Dataset.
        :param pulumi.Input[str] path: The path of the Azure Blob.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatasetAzureBlobSchemaColumnArgs']]]] schema_columns: A `schema_column` block as defined below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatasetAzureBlobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Azure Blob Dataset inside an Azure Data Factory.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.storage.get_account_output(name="storageaccountname",
            resource_group_name=example_resource_group.name)
        example_factory = azure.datafactory.Factory("exampleFactory",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        example_linked_service_azure_blob_storage = azure.datafactory.LinkedServiceAzureBlobStorage("exampleLinkedServiceAzureBlobStorage",
            data_factory_id=example_factory.id,
            connection_string=example_account.primary_connection_string)
        example_dataset_azure_blob = azure.datafactory.DatasetAzureBlob("exampleDatasetAzureBlob",
            data_factory_id=example_factory.id,
            linked_service_name=example_linked_service_azure_blob_storage.name,
            path="foo",
            filename="bar.png")
        ```

        ## Import

        Data Factory Datasets can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:datafactory/datasetAzureBlob:DatasetAzureBlob example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example/providers/Microsoft.DataFactory/factories/example/datasets/example
        ```

        :param str resource_name: The name of the resource.
        :param DatasetAzureBlobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatasetAzureBlobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            kwargs = kwargs or {}
            def _setter(key, value):
                kwargs[key] = value
            DatasetAzureBlobArgs._configure(_setter, **kwargs)
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 data_factory_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
                 dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
                 filename: Optional[pulumi.Input[str]] = None,
                 folder: Optional[pulumi.Input[str]] = None,
                 linked_service_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatasetAzureBlobSchemaColumnArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatasetAzureBlobArgs.__new__(DatasetAzureBlobArgs)

            __props__.__dict__["additional_properties"] = additional_properties
            __props__.__dict__["annotations"] = annotations
            if data_factory_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_factory_id'")
            __props__.__dict__["data_factory_id"] = data_factory_id
            __props__.__dict__["description"] = description
            __props__.__dict__["dynamic_filename_enabled"] = dynamic_filename_enabled
            __props__.__dict__["dynamic_path_enabled"] = dynamic_path_enabled
            __props__.__dict__["filename"] = filename
            __props__.__dict__["folder"] = folder
            if linked_service_name is None and not opts.urn:
                raise TypeError("Missing required property 'linked_service_name'")
            __props__.__dict__["linked_service_name"] = linked_service_name
            __props__.__dict__["name"] = name
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["path"] = path
            __props__.__dict__["schema_columns"] = schema_columns
        super(DatasetAzureBlob, __self__).__init__(
            'azure:datafactory/datasetAzureBlob:DatasetAzureBlob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            annotations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            data_factory_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dynamic_filename_enabled: Optional[pulumi.Input[bool]] = None,
            dynamic_path_enabled: Optional[pulumi.Input[bool]] = None,
            filename: Optional[pulumi.Input[str]] = None,
            folder: Optional[pulumi.Input[str]] = None,
            linked_service_name: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            path: Optional[pulumi.Input[str]] = None,
            schema_columns: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatasetAzureBlobSchemaColumnArgs']]]]] = None) -> 'DatasetAzureBlob':
        """
        Get an existing DatasetAzureBlob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_properties: A map of additional properties to associate with the Data Factory Dataset.
               
               The following supported arguments are specific to Azure Blob Dataset:
        :param pulumi.Input[Sequence[pulumi.Input[str]]] annotations: List of tags that can be used for describing the Data Factory Dataset.
        :param pulumi.Input[str] data_factory_id: The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        :param pulumi.Input[str] description: The description for the Data Factory Dataset.
        :param pulumi.Input[bool] dynamic_filename_enabled: Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[bool] dynamic_path_enabled: Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        :param pulumi.Input[str] filename: The filename of the Azure Blob.
        :param pulumi.Input[str] folder: The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        :param pulumi.Input[str] linked_service_name: The Data Factory Linked Service name in which to associate the Dataset with.
        :param pulumi.Input[str] name: Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] parameters: A map of parameters to associate with the Data Factory Dataset.
        :param pulumi.Input[str] path: The path of the Azure Blob.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatasetAzureBlobSchemaColumnArgs']]]] schema_columns: A `schema_column` block as defined below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatasetAzureBlobState.__new__(_DatasetAzureBlobState)

        __props__.__dict__["additional_properties"] = additional_properties
        __props__.__dict__["annotations"] = annotations
        __props__.__dict__["data_factory_id"] = data_factory_id
        __props__.__dict__["description"] = description
        __props__.__dict__["dynamic_filename_enabled"] = dynamic_filename_enabled
        __props__.__dict__["dynamic_path_enabled"] = dynamic_path_enabled
        __props__.__dict__["filename"] = filename
        __props__.__dict__["folder"] = folder
        __props__.__dict__["linked_service_name"] = linked_service_name
        __props__.__dict__["name"] = name
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["path"] = path
        __props__.__dict__["schema_columns"] = schema_columns
        return DatasetAzureBlob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalProperties")
    def additional_properties(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A map of additional properties to associate with the Data Factory Dataset.

        The following supported arguments are specific to Azure Blob Dataset:
        """
        return pulumi.get(self, "additional_properties")

    @property
    @pulumi.getter
    def annotations(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of tags that can be used for describing the Data Factory Dataset.
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> pulumi.Output[str]:
        """
        The Data Factory ID in which to associate the Linked Service with. Changing this forces a new resource.
        """
        return pulumi.get(self, "data_factory_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description for the Data Factory Dataset.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dynamicFilenameEnabled")
    def dynamic_filename_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Is the `filename` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_filename_enabled")

    @property
    @pulumi.getter(name="dynamicPathEnabled")
    def dynamic_path_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Is the `path` using dynamic expression, function or system variables? Defaults to `false`.
        """
        return pulumi.get(self, "dynamic_path_enabled")

    @property
    @pulumi.getter
    def filename(self) -> pulumi.Output[Optional[str]]:
        """
        The filename of the Azure Blob.
        """
        return pulumi.get(self, "filename")

    @property
    @pulumi.getter
    def folder(self) -> pulumi.Output[Optional[str]]:
        """
        The folder that this Dataset is in. If not specified, the Dataset will appear at the root level.
        """
        return pulumi.get(self, "folder")

    @property
    @pulumi.getter(name="linkedServiceName")
    def linked_service_name(self) -> pulumi.Output[str]:
        """
        The Data Factory Linked Service name in which to associate the Dataset with.
        """
        return pulumi.get(self, "linked_service_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Data Factory Dataset. Changing this forces a new resource to be created. Must be globally unique. See the [Microsoft documentation](https://docs.microsoft.com/azure/data-factory/naming-rules) for all restrictions.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A map of parameters to associate with the Data Factory Dataset.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[Optional[str]]:
        """
        The path of the Azure Blob.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="schemaColumns")
    def schema_columns(self) -> pulumi.Output[Optional[Sequence['outputs.DatasetAzureBlobSchemaColumn']]]:
        """
        A `schema_column` block as defined below.
        """
        return pulumi.get(self, "schema_columns")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSshPublicKeyResult',
    'AwaitableGetSshPublicKeyResult',
    'get_ssh_public_key',
    'get_ssh_public_key_output',
]

@pulumi.output_type
class GetSshPublicKeyResult:
    """
    A collection of values returned by getSshPublicKey.
    """
    def __init__(__self__, id=None, name=None, public_key=None, resource_group_name=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if public_key and not isinstance(public_key, str):
            raise TypeError("Expected argument 'public_key' to be a str")
        pulumi.set(__self__, "public_key", public_key)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> str:
        """
        The SSH public key used to authenticate to a virtual machine through ssh.
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "tags")


class AwaitableGetSshPublicKeyResult(GetSshPublicKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSshPublicKeyResult(
            id=self.id,
            name=self.name,
            public_key=self.public_key,
            resource_group_name=self.resource_group_name,
            tags=self.tags)


def get_ssh_public_key(name: Optional[str] = None,
                       resource_group_name: Optional[str] = None,
                       tags: Optional[Mapping[str, str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSshPublicKeyResult:
    """
    Use this data source to access information about an existing SSH Public Key.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.compute.get_ssh_public_key(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this SSH Public Key.
    :param str resource_group_name: The name of the Resource Group where the SSH Public Key exists.
    :param Mapping[str, str] tags: A mapping of tags which should be assigned to the SSH Public Key.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:compute/getSshPublicKey:getSshPublicKey', __args__, opts=opts, typ=GetSshPublicKeyResult).value

    return AwaitableGetSshPublicKeyResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        public_key=pulumi.get(__ret__, 'public_key'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        tags=pulumi.get(__ret__, 'tags'))


@_utilities.lift_output_func(get_ssh_public_key)
def get_ssh_public_key_output(name: Optional[pulumi.Input[str]] = None,
                              resource_group_name: Optional[pulumi.Input[str]] = None,
                              tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSshPublicKeyResult]:
    """
    Use this data source to access information about an existing SSH Public Key.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.compute.get_ssh_public_key(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this SSH Public Key.
    :param str resource_group_name: The name of the Resource Group where the SSH Public Key exists.
    :param Mapping[str, str] tags: A mapping of tags which should be assigned to the SSH Public Key.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ServiceInitialReplicaSet',
    'ServiceNotifications',
    'ServiceSecureLdap',
    'ServiceSecurity',
    'GetServiceNotificationResult',
    'GetServiceReplicaSetResult',
    'GetServiceSecureLdapResult',
    'GetServiceSecurityResult',
]

@pulumi.output_type
class ServiceInitialReplicaSet(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "subnetId":
            suggest = "subnet_id"
        elif key == "domainControllerIpAddresses":
            suggest = "domain_controller_ip_addresses"
        elif key == "externalAccessIpAddress":
            suggest = "external_access_ip_address"
        elif key == "serviceStatus":
            suggest = "service_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceInitialReplicaSet. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceInitialReplicaSet.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceInitialReplicaSet.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 subnet_id: str,
                 domain_controller_ip_addresses: Optional[Sequence[str]] = None,
                 external_access_ip_address: Optional[str] = None,
                 id: Optional[str] = None,
                 location: Optional[str] = None,
                 service_status: Optional[str] = None):
        """
        :param str subnet_id: The ID of the subnet in which to place the initial replica set. Changing this forces a new resource to be created.
        :param Sequence[str] domain_controller_ip_addresses: A list of subnet IP addresses for the domain controllers in the initial replica set, typically two.
        :param str external_access_ip_address: The publicly routable IP address for the domain controllers in the initial replica set.
        :param str id: A unique ID for the replica set.
        :param str location: The Azure location where the Domain Service exists. Changing this forces a new resource to be created.
        :param str service_status: The current service status for the initial replica set.
        """
        ServiceInitialReplicaSet._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            subnet_id=subnet_id,
            domain_controller_ip_addresses=domain_controller_ip_addresses,
            external_access_ip_address=external_access_ip_address,
            id=id,
            location=location,
            service_status=service_status,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             subnet_id: Optional[str] = None,
             domain_controller_ip_addresses: Optional[Sequence[str]] = None,
             external_access_ip_address: Optional[str] = None,
             id: Optional[str] = None,
             location: Optional[str] = None,
             service_status: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if subnet_id is None and 'subnetId' in kwargs:
            subnet_id = kwargs['subnetId']
        if subnet_id is None:
            raise TypeError("Missing 'subnet_id' argument")
        if domain_controller_ip_addresses is None and 'domainControllerIpAddresses' in kwargs:
            domain_controller_ip_addresses = kwargs['domainControllerIpAddresses']
        if external_access_ip_address is None and 'externalAccessIpAddress' in kwargs:
            external_access_ip_address = kwargs['externalAccessIpAddress']
        if service_status is None and 'serviceStatus' in kwargs:
            service_status = kwargs['serviceStatus']

        _setter("subnet_id", subnet_id)
        if domain_controller_ip_addresses is not None:
            _setter("domain_controller_ip_addresses", domain_controller_ip_addresses)
        if external_access_ip_address is not None:
            _setter("external_access_ip_address", external_access_ip_address)
        if id is not None:
            _setter("id", id)
        if location is not None:
            _setter("location", location)
        if service_status is not None:
            _setter("service_status", service_status)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The ID of the subnet in which to place the initial replica set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="domainControllerIpAddresses")
    def domain_controller_ip_addresses(self) -> Optional[Sequence[str]]:
        """
        A list of subnet IP addresses for the domain controllers in the initial replica set, typically two.
        """
        return pulumi.get(self, "domain_controller_ip_addresses")

    @property
    @pulumi.getter(name="externalAccessIpAddress")
    def external_access_ip_address(self) -> Optional[str]:
        """
        The publicly routable IP address for the domain controllers in the initial replica set.
        """
        return pulumi.get(self, "external_access_ip_address")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        A unique ID for the replica set.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> Optional[str]:
        """
        The Azure location where the Domain Service exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> Optional[str]:
        """
        The current service status for the initial replica set.
        """
        return pulumi.get(self, "service_status")


@pulumi.output_type
class ServiceNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "additionalRecipients":
            suggest = "additional_recipients"
        elif key == "notifyDcAdmins":
            suggest = "notify_dc_admins"
        elif key == "notifyGlobalAdmins":
            suggest = "notify_global_admins"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 additional_recipients: Optional[Sequence[str]] = None,
                 notify_dc_admins: Optional[bool] = None,
                 notify_global_admins: Optional[bool] = None):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses to notify when there are alerts in the managed domain.
        :param bool notify_dc_admins: Whether to notify members of the _AAD DC Administrators_ group when there are alerts in the managed domain.
        :param bool notify_global_admins: Whether to notify all Global Administrators when there are alerts in the managed domain.
        """
        ServiceNotifications._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            additional_recipients=additional_recipients,
            notify_dc_admins=notify_dc_admins,
            notify_global_admins=notify_global_admins,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             additional_recipients: Optional[Sequence[str]] = None,
             notify_dc_admins: Optional[bool] = None,
             notify_global_admins: Optional[bool] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if additional_recipients is None and 'additionalRecipients' in kwargs:
            additional_recipients = kwargs['additionalRecipients']
        if notify_dc_admins is None and 'notifyDcAdmins' in kwargs:
            notify_dc_admins = kwargs['notifyDcAdmins']
        if notify_global_admins is None and 'notifyGlobalAdmins' in kwargs:
            notify_global_admins = kwargs['notifyGlobalAdmins']

        if additional_recipients is not None:
            _setter("additional_recipients", additional_recipients)
        if notify_dc_admins is not None:
            _setter("notify_dc_admins", notify_dc_admins)
        if notify_global_admins is not None:
            _setter("notify_global_admins", notify_global_admins)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        A list of additional email addresses to notify when there are alerts in the managed domain.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="notifyDcAdmins")
    def notify_dc_admins(self) -> Optional[bool]:
        """
        Whether to notify members of the _AAD DC Administrators_ group when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_dc_admins")

    @property
    @pulumi.getter(name="notifyGlobalAdmins")
    def notify_global_admins(self) -> Optional[bool]:
        """
        Whether to notify all Global Administrators when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_global_admins")


@pulumi.output_type
class ServiceSecureLdap(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pfxCertificate":
            suggest = "pfx_certificate"
        elif key == "pfxCertificatePassword":
            suggest = "pfx_certificate_password"
        elif key == "certificateExpiry":
            suggest = "certificate_expiry"
        elif key == "certificateThumbprint":
            suggest = "certificate_thumbprint"
        elif key == "externalAccessEnabled":
            suggest = "external_access_enabled"
        elif key == "publicCertificate":
            suggest = "public_certificate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceSecureLdap. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceSecureLdap.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceSecureLdap.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enabled: bool,
                 pfx_certificate: str,
                 pfx_certificate_password: str,
                 certificate_expiry: Optional[str] = None,
                 certificate_thumbprint: Optional[str] = None,
                 external_access_enabled: Optional[bool] = None,
                 public_certificate: Optional[str] = None):
        """
        :param bool enabled: Whether to enable secure LDAP for the managed domain. For more information, please see [official documentation on enabling LDAPS](https://docs.microsoft.com/azure/active-directory-domain-services/tutorial-configure-ldaps), paying particular attention to the section on network security to avoid unnecessarily exposing your service to Internet-borne bruteforce attacks.
        :param str pfx_certificate: The certificate/private key to use for LDAPS, as a base64-encoded TripleDES-SHA1 encrypted PKCS#12 bundle (PFX file).
        :param str pfx_certificate_password: The password to use for decrypting the PKCS#12 bundle (PFX file).
        :param str certificate_expiry: The expiry time of the certificate.
        :param str certificate_thumbprint: The thumbprint of the certificate.
        :param bool external_access_enabled: Whether to enable external access to LDAPS over the Internet. Defaults to `false`.
        :param str public_certificate: The public certificate.
        """
        ServiceSecureLdap._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            enabled=enabled,
            pfx_certificate=pfx_certificate,
            pfx_certificate_password=pfx_certificate_password,
            certificate_expiry=certificate_expiry,
            certificate_thumbprint=certificate_thumbprint,
            external_access_enabled=external_access_enabled,
            public_certificate=public_certificate,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             enabled: Optional[bool] = None,
             pfx_certificate: Optional[str] = None,
             pfx_certificate_password: Optional[str] = None,
             certificate_expiry: Optional[str] = None,
             certificate_thumbprint: Optional[str] = None,
             external_access_enabled: Optional[bool] = None,
             public_certificate: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if enabled is None:
            raise TypeError("Missing 'enabled' argument")
        if pfx_certificate is None and 'pfxCertificate' in kwargs:
            pfx_certificate = kwargs['pfxCertificate']
        if pfx_certificate is None:
            raise TypeError("Missing 'pfx_certificate' argument")
        if pfx_certificate_password is None and 'pfxCertificatePassword' in kwargs:
            pfx_certificate_password = kwargs['pfxCertificatePassword']
        if pfx_certificate_password is None:
            raise TypeError("Missing 'pfx_certificate_password' argument")
        if certificate_expiry is None and 'certificateExpiry' in kwargs:
            certificate_expiry = kwargs['certificateExpiry']
        if certificate_thumbprint is None and 'certificateThumbprint' in kwargs:
            certificate_thumbprint = kwargs['certificateThumbprint']
        if external_access_enabled is None and 'externalAccessEnabled' in kwargs:
            external_access_enabled = kwargs['externalAccessEnabled']
        if public_certificate is None and 'publicCertificate' in kwargs:
            public_certificate = kwargs['publicCertificate']

        _setter("enabled", enabled)
        _setter("pfx_certificate", pfx_certificate)
        _setter("pfx_certificate_password", pfx_certificate_password)
        if certificate_expiry is not None:
            _setter("certificate_expiry", certificate_expiry)
        if certificate_thumbprint is not None:
            _setter("certificate_thumbprint", certificate_thumbprint)
        if external_access_enabled is not None:
            _setter("external_access_enabled", external_access_enabled)
        if public_certificate is not None:
            _setter("public_certificate", public_certificate)

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Whether to enable secure LDAP for the managed domain. For more information, please see [official documentation on enabling LDAPS](https://docs.microsoft.com/azure/active-directory-domain-services/tutorial-configure-ldaps), paying particular attention to the section on network security to avoid unnecessarily exposing your service to Internet-borne bruteforce attacks.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="pfxCertificate")
    def pfx_certificate(self) -> str:
        """
        The certificate/private key to use for LDAPS, as a base64-encoded TripleDES-SHA1 encrypted PKCS#12 bundle (PFX file).
        """
        return pulumi.get(self, "pfx_certificate")

    @property
    @pulumi.getter(name="pfxCertificatePassword")
    def pfx_certificate_password(self) -> str:
        """
        The password to use for decrypting the PKCS#12 bundle (PFX file).
        """
        return pulumi.get(self, "pfx_certificate_password")

    @property
    @pulumi.getter(name="certificateExpiry")
    def certificate_expiry(self) -> Optional[str]:
        """
        The expiry time of the certificate.
        """
        return pulumi.get(self, "certificate_expiry")

    @property
    @pulumi.getter(name="certificateThumbprint")
    def certificate_thumbprint(self) -> Optional[str]:
        """
        The thumbprint of the certificate.
        """
        return pulumi.get(self, "certificate_thumbprint")

    @property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> Optional[bool]:
        """
        Whether to enable external access to LDAPS over the Internet. Defaults to `false`.
        """
        return pulumi.get(self, "external_access_enabled")

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> Optional[str]:
        """
        The public certificate.
        """
        return pulumi.get(self, "public_certificate")


@pulumi.output_type
class ServiceSecurity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "kerberosArmoringEnabled":
            suggest = "kerberos_armoring_enabled"
        elif key == "kerberosRc4EncryptionEnabled":
            suggest = "kerberos_rc4_encryption_enabled"
        elif key == "ntlmV1Enabled":
            suggest = "ntlm_v1_enabled"
        elif key == "syncKerberosPasswords":
            suggest = "sync_kerberos_passwords"
        elif key == "syncNtlmPasswords":
            suggest = "sync_ntlm_passwords"
        elif key == "syncOnPremPasswords":
            suggest = "sync_on_prem_passwords"
        elif key == "tlsV1Enabled":
            suggest = "tls_v1_enabled"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceSecurity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceSecurity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceSecurity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 kerberos_armoring_enabled: Optional[bool] = None,
                 kerberos_rc4_encryption_enabled: Optional[bool] = None,
                 ntlm_v1_enabled: Optional[bool] = None,
                 sync_kerberos_passwords: Optional[bool] = None,
                 sync_ntlm_passwords: Optional[bool] = None,
                 sync_on_prem_passwords: Optional[bool] = None,
                 tls_v1_enabled: Optional[bool] = None):
        """
        :param bool kerberos_armoring_enabled: Whether to enable Kerberos Armoring. Defaults to `false`.
        :param bool kerberos_rc4_encryption_enabled: Whether to enable Kerberos RC4 Encryption. Defaults to `false`.
        :param bool ntlm_v1_enabled: Whether to enable legacy NTLM v1 support. Defaults to `false`.
        :param bool sync_kerberos_passwords: Whether to synchronize Kerberos password hashes to the managed domain. Defaults to `false`.
        :param bool sync_ntlm_passwords: Whether to synchronize NTLM password hashes to the managed domain. Defaults to `false`.
        :param bool sync_on_prem_passwords: Whether to synchronize on-premises password hashes to the managed domain. Defaults to `false`.
        :param bool tls_v1_enabled: Whether to enable legacy TLS v1 support. Defaults to `false`.
        """
        ServiceSecurity._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            kerberos_armoring_enabled=kerberos_armoring_enabled,
            kerberos_rc4_encryption_enabled=kerberos_rc4_encryption_enabled,
            ntlm_v1_enabled=ntlm_v1_enabled,
            sync_kerberos_passwords=sync_kerberos_passwords,
            sync_ntlm_passwords=sync_ntlm_passwords,
            sync_on_prem_passwords=sync_on_prem_passwords,
            tls_v1_enabled=tls_v1_enabled,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             kerberos_armoring_enabled: Optional[bool] = None,
             kerberos_rc4_encryption_enabled: Optional[bool] = None,
             ntlm_v1_enabled: Optional[bool] = None,
             sync_kerberos_passwords: Optional[bool] = None,
             sync_ntlm_passwords: Optional[bool] = None,
             sync_on_prem_passwords: Optional[bool] = None,
             tls_v1_enabled: Optional[bool] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if kerberos_armoring_enabled is None and 'kerberosArmoringEnabled' in kwargs:
            kerberos_armoring_enabled = kwargs['kerberosArmoringEnabled']
        if kerberos_rc4_encryption_enabled is None and 'kerberosRc4EncryptionEnabled' in kwargs:
            kerberos_rc4_encryption_enabled = kwargs['kerberosRc4EncryptionEnabled']
        if ntlm_v1_enabled is None and 'ntlmV1Enabled' in kwargs:
            ntlm_v1_enabled = kwargs['ntlmV1Enabled']
        if sync_kerberos_passwords is None and 'syncKerberosPasswords' in kwargs:
            sync_kerberos_passwords = kwargs['syncKerberosPasswords']
        if sync_ntlm_passwords is None and 'syncNtlmPasswords' in kwargs:
            sync_ntlm_passwords = kwargs['syncNtlmPasswords']
        if sync_on_prem_passwords is None and 'syncOnPremPasswords' in kwargs:
            sync_on_prem_passwords = kwargs['syncOnPremPasswords']
        if tls_v1_enabled is None and 'tlsV1Enabled' in kwargs:
            tls_v1_enabled = kwargs['tlsV1Enabled']

        if kerberos_armoring_enabled is not None:
            _setter("kerberos_armoring_enabled", kerberos_armoring_enabled)
        if kerberos_rc4_encryption_enabled is not None:
            _setter("kerberos_rc4_encryption_enabled", kerberos_rc4_encryption_enabled)
        if ntlm_v1_enabled is not None:
            _setter("ntlm_v1_enabled", ntlm_v1_enabled)
        if sync_kerberos_passwords is not None:
            _setter("sync_kerberos_passwords", sync_kerberos_passwords)
        if sync_ntlm_passwords is not None:
            _setter("sync_ntlm_passwords", sync_ntlm_passwords)
        if sync_on_prem_passwords is not None:
            _setter("sync_on_prem_passwords", sync_on_prem_passwords)
        if tls_v1_enabled is not None:
            _setter("tls_v1_enabled", tls_v1_enabled)

    @property
    @pulumi.getter(name="kerberosArmoringEnabled")
    def kerberos_armoring_enabled(self) -> Optional[bool]:
        """
        Whether to enable Kerberos Armoring. Defaults to `false`.
        """
        return pulumi.get(self, "kerberos_armoring_enabled")

    @property
    @pulumi.getter(name="kerberosRc4EncryptionEnabled")
    def kerberos_rc4_encryption_enabled(self) -> Optional[bool]:
        """
        Whether to enable Kerberos RC4 Encryption. Defaults to `false`.
        """
        return pulumi.get(self, "kerberos_rc4_encryption_enabled")

    @property
    @pulumi.getter(name="ntlmV1Enabled")
    def ntlm_v1_enabled(self) -> Optional[bool]:
        """
        Whether to enable legacy NTLM v1 support. Defaults to `false`.
        """
        return pulumi.get(self, "ntlm_v1_enabled")

    @property
    @pulumi.getter(name="syncKerberosPasswords")
    def sync_kerberos_passwords(self) -> Optional[bool]:
        """
        Whether to synchronize Kerberos password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_kerberos_passwords")

    @property
    @pulumi.getter(name="syncNtlmPasswords")
    def sync_ntlm_passwords(self) -> Optional[bool]:
        """
        Whether to synchronize NTLM password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_ntlm_passwords")

    @property
    @pulumi.getter(name="syncOnPremPasswords")
    def sync_on_prem_passwords(self) -> Optional[bool]:
        """
        Whether to synchronize on-premises password hashes to the managed domain. Defaults to `false`.
        """
        return pulumi.get(self, "sync_on_prem_passwords")

    @property
    @pulumi.getter(name="tlsV1Enabled")
    def tls_v1_enabled(self) -> Optional[bool]:
        """
        Whether to enable legacy TLS v1 support. Defaults to `false`.
        """
        return pulumi.get(self, "tls_v1_enabled")


@pulumi.output_type
class GetServiceNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 notify_dc_admins: bool,
                 notify_global_admins: bool):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses to notify when there are alerts in the managed domain.
        :param bool notify_dc_admins: Whethermembers of the _AAD DC Administrators_ group are notified when there are alerts in the managed domain.
        :param bool notify_global_admins: Whether all Global Administrators are notified when there are alerts in the managed domain.
        """
        GetServiceNotificationResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            additional_recipients=additional_recipients,
            notify_dc_admins=notify_dc_admins,
            notify_global_admins=notify_global_admins,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             additional_recipients: Optional[Sequence[str]] = None,
             notify_dc_admins: Optional[bool] = None,
             notify_global_admins: Optional[bool] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if additional_recipients is None and 'additionalRecipients' in kwargs:
            additional_recipients = kwargs['additionalRecipients']
        if additional_recipients is None:
            raise TypeError("Missing 'additional_recipients' argument")
        if notify_dc_admins is None and 'notifyDcAdmins' in kwargs:
            notify_dc_admins = kwargs['notifyDcAdmins']
        if notify_dc_admins is None:
            raise TypeError("Missing 'notify_dc_admins' argument")
        if notify_global_admins is None and 'notifyGlobalAdmins' in kwargs:
            notify_global_admins = kwargs['notifyGlobalAdmins']
        if notify_global_admins is None:
            raise TypeError("Missing 'notify_global_admins' argument")

        _setter("additional_recipients", additional_recipients)
        _setter("notify_dc_admins", notify_dc_admins)
        _setter("notify_global_admins", notify_global_admins)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses to notify when there are alerts in the managed domain.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="notifyDcAdmins")
    def notify_dc_admins(self) -> bool:
        """
        Whethermembers of the _AAD DC Administrators_ group are notified when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_dc_admins")

    @property
    @pulumi.getter(name="notifyGlobalAdmins")
    def notify_global_admins(self) -> bool:
        """
        Whether all Global Administrators are notified when there are alerts in the managed domain.
        """
        return pulumi.get(self, "notify_global_admins")


@pulumi.output_type
class GetServiceReplicaSetResult(dict):
    def __init__(__self__, *,
                 domain_controller_ip_addresses: Sequence[str],
                 external_access_ip_address: str,
                 id: str,
                 location: str,
                 service_status: str,
                 subnet_id: str):
        """
        :param Sequence[str] domain_controller_ip_addresses: A list of subnet IP addresses for the domain controllers in the replica set, typically two.
        :param str external_access_ip_address: The publicly routable IP address for the domain controllers in the replica set.
        :param str id: The ID of the Domain Service.
        :param str location: The Azure location in which the replica set resides.
        :param str service_status: The current service status for the replica set.
        :param str subnet_id: The ID of the subnet in which the replica set resides.
        """
        GetServiceReplicaSetResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            domain_controller_ip_addresses=domain_controller_ip_addresses,
            external_access_ip_address=external_access_ip_address,
            id=id,
            location=location,
            service_status=service_status,
            subnet_id=subnet_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             domain_controller_ip_addresses: Optional[Sequence[str]] = None,
             external_access_ip_address: Optional[str] = None,
             id: Optional[str] = None,
             location: Optional[str] = None,
             service_status: Optional[str] = None,
             subnet_id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if domain_controller_ip_addresses is None and 'domainControllerIpAddresses' in kwargs:
            domain_controller_ip_addresses = kwargs['domainControllerIpAddresses']
        if domain_controller_ip_addresses is None:
            raise TypeError("Missing 'domain_controller_ip_addresses' argument")
        if external_access_ip_address is None and 'externalAccessIpAddress' in kwargs:
            external_access_ip_address = kwargs['externalAccessIpAddress']
        if external_access_ip_address is None:
            raise TypeError("Missing 'external_access_ip_address' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if location is None:
            raise TypeError("Missing 'location' argument")
        if service_status is None and 'serviceStatus' in kwargs:
            service_status = kwargs['serviceStatus']
        if service_status is None:
            raise TypeError("Missing 'service_status' argument")
        if subnet_id is None and 'subnetId' in kwargs:
            subnet_id = kwargs['subnetId']
        if subnet_id is None:
            raise TypeError("Missing 'subnet_id' argument")

        _setter("domain_controller_ip_addresses", domain_controller_ip_addresses)
        _setter("external_access_ip_address", external_access_ip_address)
        _setter("id", id)
        _setter("location", location)
        _setter("service_status", service_status)
        _setter("subnet_id", subnet_id)

    @property
    @pulumi.getter(name="domainControllerIpAddresses")
    def domain_controller_ip_addresses(self) -> Sequence[str]:
        """
        A list of subnet IP addresses for the domain controllers in the replica set, typically two.
        """
        return pulumi.get(self, "domain_controller_ip_addresses")

    @property
    @pulumi.getter(name="externalAccessIpAddress")
    def external_access_ip_address(self) -> str:
        """
        The publicly routable IP address for the domain controllers in the replica set.
        """
        return pulumi.get(self, "external_access_ip_address")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Domain Service.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The Azure location in which the replica set resides.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> str:
        """
        The current service status for the replica set.
        """
        return pulumi.get(self, "service_status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The ID of the subnet in which the replica set resides.
        """
        return pulumi.get(self, "subnet_id")


@pulumi.output_type
class GetServiceSecureLdapResult(dict):
    def __init__(__self__, *,
                 certificate_expiry: str,
                 certificate_thumbprint: str,
                 enabled: bool,
                 external_access_enabled: bool,
                 public_certificate: str):
        """
        :param bool enabled: Whether secure LDAP is enabled for the managed domain.
        :param bool external_access_enabled: Whether external access to LDAPS over the Internet, is enabled.
        """
        GetServiceSecureLdapResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            certificate_expiry=certificate_expiry,
            certificate_thumbprint=certificate_thumbprint,
            enabled=enabled,
            external_access_enabled=external_access_enabled,
            public_certificate=public_certificate,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             certificate_expiry: Optional[str] = None,
             certificate_thumbprint: Optional[str] = None,
             enabled: Optional[bool] = None,
             external_access_enabled: Optional[bool] = None,
             public_certificate: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if certificate_expiry is None and 'certificateExpiry' in kwargs:
            certificate_expiry = kwargs['certificateExpiry']
        if certificate_expiry is None:
            raise TypeError("Missing 'certificate_expiry' argument")
        if certificate_thumbprint is None and 'certificateThumbprint' in kwargs:
            certificate_thumbprint = kwargs['certificateThumbprint']
        if certificate_thumbprint is None:
            raise TypeError("Missing 'certificate_thumbprint' argument")
        if enabled is None:
            raise TypeError("Missing 'enabled' argument")
        if external_access_enabled is None and 'externalAccessEnabled' in kwargs:
            external_access_enabled = kwargs['externalAccessEnabled']
        if external_access_enabled is None:
            raise TypeError("Missing 'external_access_enabled' argument")
        if public_certificate is None and 'publicCertificate' in kwargs:
            public_certificate = kwargs['publicCertificate']
        if public_certificate is None:
            raise TypeError("Missing 'public_certificate' argument")

        _setter("certificate_expiry", certificate_expiry)
        _setter("certificate_thumbprint", certificate_thumbprint)
        _setter("enabled", enabled)
        _setter("external_access_enabled", external_access_enabled)
        _setter("public_certificate", public_certificate)

    @property
    @pulumi.getter(name="certificateExpiry")
    def certificate_expiry(self) -> str:
        return pulumi.get(self, "certificate_expiry")

    @property
    @pulumi.getter(name="certificateThumbprint")
    def certificate_thumbprint(self) -> str:
        return pulumi.get(self, "certificate_thumbprint")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Whether secure LDAP is enabled for the managed domain.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> bool:
        """
        Whether external access to LDAPS over the Internet, is enabled.
        """
        return pulumi.get(self, "external_access_enabled")

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> str:
        return pulumi.get(self, "public_certificate")


@pulumi.output_type
class GetServiceSecurityResult(dict):
    def __init__(__self__, *,
                 kerberos_armoring_enabled: bool,
                 kerberos_rc4_encryption_enabled: bool,
                 ntlm_v1_enabled: bool,
                 sync_kerberos_passwords: bool,
                 sync_ntlm_passwords: bool,
                 sync_on_prem_passwords: bool,
                 tls_v1_enabled: bool):
        """
        :param bool kerberos_armoring_enabled: (Optional) Whether the Kerberos Armoring is enabled.
        :param bool kerberos_rc4_encryption_enabled: (Optional) Whether the Kerberos RC4 Encryption is enabled.
        :param bool ntlm_v1_enabled: Whether legacy NTLM v1 support is enabled.
        :param bool sync_kerberos_passwords: Whether Kerberos password hashes are synchronized to the managed domain.
        :param bool sync_ntlm_passwords: Whether NTLM password hashes are synchronized to the managed domain.
        :param bool sync_on_prem_passwords: Whether on-premises password hashes are synchronized to the managed domain.
        :param bool tls_v1_enabled: Whether legacy TLS v1 support is enabled.
        """
        GetServiceSecurityResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            kerberos_armoring_enabled=kerberos_armoring_enabled,
            kerberos_rc4_encryption_enabled=kerberos_rc4_encryption_enabled,
            ntlm_v1_enabled=ntlm_v1_enabled,
            sync_kerberos_passwords=sync_kerberos_passwords,
            sync_ntlm_passwords=sync_ntlm_passwords,
            sync_on_prem_passwords=sync_on_prem_passwords,
            tls_v1_enabled=tls_v1_enabled,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             kerberos_armoring_enabled: Optional[bool] = None,
             kerberos_rc4_encryption_enabled: Optional[bool] = None,
             ntlm_v1_enabled: Optional[bool] = None,
             sync_kerberos_passwords: Optional[bool] = None,
             sync_ntlm_passwords: Optional[bool] = None,
             sync_on_prem_passwords: Optional[bool] = None,
             tls_v1_enabled: Optional[bool] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if kerberos_armoring_enabled is None and 'kerberosArmoringEnabled' in kwargs:
            kerberos_armoring_enabled = kwargs['kerberosArmoringEnabled']
        if kerberos_armoring_enabled is None:
            raise TypeError("Missing 'kerberos_armoring_enabled' argument")
        if kerberos_rc4_encryption_enabled is None and 'kerberosRc4EncryptionEnabled' in kwargs:
            kerberos_rc4_encryption_enabled = kwargs['kerberosRc4EncryptionEnabled']
        if kerberos_rc4_encryption_enabled is None:
            raise TypeError("Missing 'kerberos_rc4_encryption_enabled' argument")
        if ntlm_v1_enabled is None and 'ntlmV1Enabled' in kwargs:
            ntlm_v1_enabled = kwargs['ntlmV1Enabled']
        if ntlm_v1_enabled is None:
            raise TypeError("Missing 'ntlm_v1_enabled' argument")
        if sync_kerberos_passwords is None and 'syncKerberosPasswords' in kwargs:
            sync_kerberos_passwords = kwargs['syncKerberosPasswords']
        if sync_kerberos_passwords is None:
            raise TypeError("Missing 'sync_kerberos_passwords' argument")
        if sync_ntlm_passwords is None and 'syncNtlmPasswords' in kwargs:
            sync_ntlm_passwords = kwargs['syncNtlmPasswords']
        if sync_ntlm_passwords is None:
            raise TypeError("Missing 'sync_ntlm_passwords' argument")
        if sync_on_prem_passwords is None and 'syncOnPremPasswords' in kwargs:
            sync_on_prem_passwords = kwargs['syncOnPremPasswords']
        if sync_on_prem_passwords is None:
            raise TypeError("Missing 'sync_on_prem_passwords' argument")
        if tls_v1_enabled is None and 'tlsV1Enabled' in kwargs:
            tls_v1_enabled = kwargs['tlsV1Enabled']
        if tls_v1_enabled is None:
            raise TypeError("Missing 'tls_v1_enabled' argument")

        _setter("kerberos_armoring_enabled", kerberos_armoring_enabled)
        _setter("kerberos_rc4_encryption_enabled", kerberos_rc4_encryption_enabled)
        _setter("ntlm_v1_enabled", ntlm_v1_enabled)
        _setter("sync_kerberos_passwords", sync_kerberos_passwords)
        _setter("sync_ntlm_passwords", sync_ntlm_passwords)
        _setter("sync_on_prem_passwords", sync_on_prem_passwords)
        _setter("tls_v1_enabled", tls_v1_enabled)

    @property
    @pulumi.getter(name="kerberosArmoringEnabled")
    def kerberos_armoring_enabled(self) -> bool:
        """
        (Optional) Whether the Kerberos Armoring is enabled.
        """
        return pulumi.get(self, "kerberos_armoring_enabled")

    @property
    @pulumi.getter(name="kerberosRc4EncryptionEnabled")
    def kerberos_rc4_encryption_enabled(self) -> bool:
        """
        (Optional) Whether the Kerberos RC4 Encryption is enabled.
        """
        return pulumi.get(self, "kerberos_rc4_encryption_enabled")

    @property
    @pulumi.getter(name="ntlmV1Enabled")
    def ntlm_v1_enabled(self) -> bool:
        """
        Whether legacy NTLM v1 support is enabled.
        """
        return pulumi.get(self, "ntlm_v1_enabled")

    @property
    @pulumi.getter(name="syncKerberosPasswords")
    def sync_kerberos_passwords(self) -> bool:
        """
        Whether Kerberos password hashes are synchronized to the managed domain.
        """
        return pulumi.get(self, "sync_kerberos_passwords")

    @property
    @pulumi.getter(name="syncNtlmPasswords")
    def sync_ntlm_passwords(self) -> bool:
        """
        Whether NTLM password hashes are synchronized to the managed domain.
        """
        return pulumi.get(self, "sync_ntlm_passwords")

    @property
    @pulumi.getter(name="syncOnPremPasswords")
    def sync_on_prem_passwords(self) -> bool:
        """
        Whether on-premises password hashes are synchronized to the managed domain.
        """
        return pulumi.get(self, "sync_on_prem_passwords")

    @property
    @pulumi.getter(name="tlsV1Enabled")
    def tls_v1_enabled(self) -> bool:
        """
        Whether legacy TLS v1 support is enabled.
        """
        return pulumi.get(self, "tls_v1_enabled")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ServerIpv4FirewallRule',
]

@pulumi.output_type
class ServerIpv4FirewallRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "rangeEnd":
            suggest = "range_end"
        elif key == "rangeStart":
            suggest = "range_start"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServerIpv4FirewallRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServerIpv4FirewallRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServerIpv4FirewallRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 range_end: str,
                 range_start: str):
        """
        :param str name: Specifies the name of the firewall rule.
        :param str range_end: End of the firewall rule range as IPv4 address.
        :param str range_start: Start of the firewall rule range as IPv4 address.
        """
        ServerIpv4FirewallRule._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            name=name,
            range_end=range_end,
            range_start=range_start,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             name: Optional[str] = None,
             range_end: Optional[str] = None,
             range_start: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if name is None:
            raise TypeError("Missing 'name' argument")
        if range_end is None and 'rangeEnd' in kwargs:
            range_end = kwargs['rangeEnd']
        if range_end is None:
            raise TypeError("Missing 'range_end' argument")
        if range_start is None and 'rangeStart' in kwargs:
            range_start = kwargs['rangeStart']
        if range_start is None:
            raise TypeError("Missing 'range_start' argument")

        _setter("name", name)
        _setter("range_end", range_end)
        _setter("range_start", range_start)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specifies the name of the firewall rule.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rangeEnd")
    def range_end(self) -> str:
        """
        End of the firewall rule range as IPv4 address.
        """
        return pulumi.get(self, "range_end")

    @property
    @pulumi.getter(name="rangeStart")
    def range_start(self) -> str:
        """
        Start of the firewall rule range as IPv4 address.
        """
        return pulumi.get(self, "range_start")


